from pydantic import BaseModel


class FinamDecimal(BaseModel):
    """
    A custom decimal type for Finam API responses.
    """
    value: str = "0.0"


class FinamDate(BaseModel):
    """
    A custom date type for Finam API responses.
    """
    year: int
    month: int
    day: int


class FinamMoney(BaseModel):
    """
    A custom money type for Finam API responses.
    """
    units: str = "0"
    currencyCode: str = "RUB"
    nanos: int = 0



from finam_trade_api import TokenManager
from finam_trade_api.base_client import BaseClient


class OrderClient(BaseClient):
    def __init__(self, token_manager: TokenManager):
        super().__init__(token_manager)
        self._url = "/accounts"

    async def get_orders(self):
        raise NotImplementedError

    async def get_order(self):
        raise NotImplementedError

    async def place_order(self):
        raise NotImplementedError

    async def cancel_order(self):
        raise NotImplementedError



from datetime import datetime

from pydantic import BaseModel


class MDPermission(BaseModel):
    quoteLevel: str
    delayMinutes: int
    mic: str
    country: str | None = None
    continent: str | None = None
    worldwide: bool = False


class TokenDetailsResponse(BaseModel):
    createdAt: datetime
    expiresAt: datetime
    mdPermissions: list[MDPermission]
    accountIds: list[str]



from datetime import datetime

from pydantic import BaseModel, Field

from finam_trade_api.base_client.models import FinamDecimal


class Position(BaseModel):
    symbol: str
    quantity: FinamDecimal
    averagePrice: FinamDecimal
    currentPrice: FinamDecimal


class GetAccountResponse(BaseModel):
    accountId: str
    type: str
    status: str
    equity: FinamDecimal
    unrealizedProfit: FinamDecimal
    positions: list[Position] = Field(default_factory=list)
    cash: list = Field(default_factory=list)  # todo не задокументировано


class GetTransactionsRequest(BaseModel):
    account_id: str
    start_time: str
    end_time: str
    limit: int = 10


class GetTradesRequest(GetTransactionsRequest):
    ...


class MoneyChange(BaseModel):
    currencyCode: str
    units: str
    nanos: int


class Trade(BaseModel):
    size: FinamDecimal
    price: FinamDecimal
    accruedInterest: FinamDecimal


class Transaction(BaseModel):
    id: str
    category: str
    timestamp: str
    symbol: str
    change: MoneyChange | None = None
    trade: Trade | None = None


class GetTransactionsResponse(BaseModel):
    transactions: list[Transaction]


class AccountTrade(BaseModel):
    tradeId: str
    symbol: str
    price: FinamDecimal
    size: FinamDecimal
    side: str
    timestamp: datetime


class GetTradesResponse(BaseModel):
    trades: list[AccountTrade]
